﻿using System;
using System.Net;
using System.Collections.Generic;

namespace Geodesic
{
	public static class POIs
	{
		public class Poi
		{
			public string Title { get; set; }
			public double Longitude;
			public double Latitude;
		}
		public class DistanceLine
		{
			public Poi Poi { get; set; }
			public LineSegments Line { get; set; }
		}
		public static IEnumerable<DistanceLine> GetLines(Point location)
		{
			return GetLines(GetPOIs(), location);
		}
		public static IEnumerable<DistanceLine> GetLines(IEnumerable<Poi> pois, Point location)
		{
			foreach (var poi in pois)
			{
				LineSegments segments = Geodesic.GetGeodesicLine(new Point(poi.Longitude, poi.Latitude), location);
				yield return new DistanceLine() { Line = segments, Poi = poi };
			}
		}

		private static IEnumerable<Poi> GetPOIs()
		{
			yield return new Poi()
				{
					Title = "Copenhagen",
					Latitude = 55.67593,
					Longitude = 12.56911
				};
			yield return new Poi()
				{
					Title = "London",
					Latitude = 51.504,
					Longitude = -.1035
				};
			yield return new Poi()
				{
					Title = "Los Angeles",
					Latitude = 34.5,
					Longitude = -118.25
				};
			yield return new Poi()
				{
					Title = "Seattle",
					Latitude = 47.6205,
					Longitude = -122.3493
				};
			yield return new Poi()
				{
					Title = "New York",
					Latitude = 40.77879,
					Longitude = -73.968394
				};
			yield return new Poi()
				{
					Title = "Melbourne",
					Latitude = -37.8109,
					Longitude = 144.948
				};
			yield return new Poi()
				{
					Title = "Hong Kong",
					Latitude = 22.3321,
					Longitude = 114.1604
				};
			yield return new Poi()
				{
					Title = "Tokyo",
					Latitude = 35.68174,
					Longitude = 139.76482
				};
		}
	}
}
