﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using ESRI.ArcGIS.Client;
using ESRI.ArcGIS.Client.Geometry;
using ESRI.ArcGIS.Client.Symbols;
using ESRI.ArcGIS.Client.Tasks;

namespace MyMapApp.Controls
{
	public partial class MapView : UserControl
	{
		public MapView()
		{
			InitializeComponent();
#if !NET35
			MyMap.MapGesture += MyMap_MapGesture;									//Touch events not supported in this version of .NET3.5 ESRI API
#endif
			UpdateDistanceLines(new MapPoint(-13178130, 4032073));					//LASLUG Event location in Mercator projection units
		}
#if !NET35
		private void MyMap_MapGesture(object sender, Map.MapGestureEventArgs e)
		{
			if (e.Gesture == GestureType.Tap)
				UpdateDistanceLines(e.MapPoint);
		}
#endif

		private void MyMap_MouseClick(object sender, ESRI.ArcGIS.Client.Map.MouseEventArgs e)
		{
			UpdateDistanceLines(e.MapPoint);
		}

		private void UpdateDistanceLines(ESRI.ArcGIS.Client.Geometry.MapPoint p)
		{
			//Update graphics layer with calculated distance lines
			ESRI.ArcGIS.Client.Projection.WebMercator proj = new ESRI.ArcGIS.Client.Projection.WebMercator();
			var layer = MyMap.Layers[1] as GraphicsLayer;
			layer.Graphics.Clear();
			p = proj.ToGeographic(p) as MapPoint; //Convert to lat/long
			//Iterate through POIs
			foreach(var dl in Geodesic.POIs.GetLines(new Geodesic.Point(p.X,p.Y)))
			{
				Polyline line = new Polyline();
				foreach (var pnts in dl.Line)
				{
					PointCollection path = new PointCollection();
					foreach (var pnt in pnts)
						path.Add(new MapPoint(pnt.Longitude, pnt.Latitude));
					line.Paths.Add(path);
				}
				Graphic g2 = new Graphic()
				{
					Geometry = proj.FromGeographic(line),
					Symbol = new SimpleLineSymbol()
					{
						Color = new System.Windows.Media.SolidColorBrush(System.Windows.Media.Colors.Red),
						Width = 2
					}
				};
				g2.Attributes["poi"] = dl.Poi.Title;
				layer.Graphics.Add(g2);
			}
		}

		private void LayerInitializationFailed(object sender, EventArgs e)
		{
			//TODO: Handle this
		}
	}
}
